@@ -5,9 +5,9 @@ from time import sleep
 
 def caput(pvname, value, wait=False, timeout=60.0, bak=backUpVals, tramp=None):
     val = epics.caget(pvname, timeout=timeout)
-    if all([ele['name'] != pvname for ele in bak]):
-        bak += [{'type': 'channel', 'name': pvname, 'value': val,
-                 'tramp': tramp}]
+    if pvname not in bak:
+        bak[pvname] = {'type': 'channel', 'value': val, 'tramp': tramp,
+                       'sno': len(bak), 'name': pvname}
     if tramp is None:
         epics.caput(pvname=pvname, value=value, wait=wait, timeout=timeout)
     else:
